@@ -35,7 +35,6 @@
 #include <stdlib.h>
 
 #include "keditbookmarks_debug.h"
-#include <kxmlgui_version.h>
 
 #include <QApplication>
 #include <QClipboard>
@@ -75,11 +74,7 @@ void KEBApp::createActions()
     // save and quit should probably not be in the toplevel???
     (void)KStandardAction::quit(this, SLOT(close()), actionCollection());
 
-#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 84, 0)
     KStandardAction::keyBindings(guiFactory(), &KXMLGUIFactory::showConfigureShortcutsDialog, actionCollection());
-#else
-    KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
-#endif
 
     (void)KStandardAction::configureToolbars(this, SLOT(slotConfigureToolbars()), actionCollection());
 
